==> SomatiCA_1.0.0.tar.gz: SomatiCA/R/subclonality.R <==
subclonality <- function(segment, admix, bin=0.1){
### Written by Mengjie Chen, Nov 2012 ###
### Estimation of subclonality for each segment ###	
	
	if(class(segment)!="GRanges")
	stop("Wrong input format! Check the manual") 
	z <- as(segment, "data.frame")
	z$germlineA <- round(z$nRcorrected)*2*(z$medgLAF)
	z$germlineB <- round(z$nRcorrected)*2*(1-z$medgLAF)		
	z$nA <- (z$tRcorrected*2*(z$medLAF)-admix)/(1-admix)
	z$nB <- (z$tRcorrected*2*(1-z$medLAF)-admix)/(1-admix)
	z$nA[z$nA < 0] <- 0
	z$nB[z$nB < 0] <- 0
	
	z$germlineAinteger <- round(z$germlineA)
	z$germlineBinteger <- round(z$germlineB) 
	z$germlinecopynumber <- z$germlineAinteger+z$germlineBinteger
  z$germlinecopynumber[z$germlinecopynumber==1 & z$medgermlineLAF>0.2 ] <- 2
  z$somaCN[z$germlinecopynumber==0 ] <- 2
	z$event[z$germlinecopynumber==0] <- "="
  
  z$ratio <- (z$ratio-admix)/(1-admix) 
	z$ratio[z$ratio<0 ] <- 0 
  z$copyRatio <- ifelse(z$ratio >= 1, 
						  (z$germlinecopynumber+1)/(z$germlinecopynumber),
						  (z$germlinecopynumber-1)/(z$germlinecopynumber))
	
	z$subclonalP <- ifelse(z$ratio >= z$copyRatio, 
						   2-2*pnorm(z$ratio, z$copyRatio, 0.1),
						   2*pnorm(z$ratio, z$copyRatio, 0.1))
  
	z$clonality <- "=" 				
	z$clonality[z$subclonalP<=0.05] <- "subclonal"
	z$clonality[z$copyRatio!=1 & z$subclonalP>0.05 & abs(z$ratio - 1)>0.05 ] <- "clonal"
	z$clonality[z$ratio > 1.6] <- "clonal"
	z$clonality[abs(z$medgLAF-z$medLAF)<0.02 & z$event=="="] <- "="
  
	z$subpercent <- ifelse(z$clonality!="subclonal", 0, round(abs(1-z$ratio)*(z$germlinecopynumber), 3))					
	z$subclonalP[round(z$subpercent, 1)>=0.9] <- 1
	z$subclonalP[z$subpercent<0.1 & z$subpercent>0] <- 1
	z$clonality[round(z$subpercent, 1)>=0.9] <- "clonal"	
	z$clonality[z$subpercent<0.1 & z$subpercent>0] <- "="	
	z$subpercent[round(z$subpercent, 1)>=0.9] <- 1
	z$subpercent[z$subpercent<0.1] <- 0
	z$subpercent[z$clonality=="clonal"] <- 1
	z$subpercent <- floor(z$subpercent/bin)*bin
	z$clonality[z$subpercent==0] <- "="	
	z$subclonecopynumber <- ifelse(z$clonality == "=", z$germlinecopynumber, 														
                          ifelse(z$clonality == "clonal", round(z$germlinecopynumber*z$ratio),	
                          ifelse(z$ratio>1, 1 + z$germlinecopynumber, z$germlinecopynumber - 1)))
  z$clonality[z$germlinecopynumber==z$subclonecopynumber & z$somaCN==2] <- "="
	z$event[z$germlinecopynumber==z$subclonecopynumber & z$somaCN==2] <- "="
	z$subpercent[z$clonality=="="] <- 0
	z$clonality[z$ratio>1 & z$clonality=="subclonal"] <- "subclonal_gain"
	z$clonality[z$ratio<1 & z$clonality=="subclonal"] <- "subclonal_loss"
	z[, c("clonality", "event")] <- apply(z[, c("clonality", "event")], 2, as.character)
	z$event[z$clonality == "clonal" & z$germlinecopynumber > z$subclonecopynumber & z$event=="="] <- "Loss"
	z$event[z$clonality == "clonal" & z$germlinecopynumber < z$subclonecopynumber & z$event=="="] <- "Gain"
	res <- GRanges(seqnames=z$seqnames, 
	                 ranges=IRanges(start=z$start, end=z$end),
	                 medLAF=z$medLAF,
	                 medgLAF=z$medgLAF,
	                 ratio=z$ratio,
	                 somaCN=z$somaCN, 
	                 event=z$event,
	                 clonality=z$clonality,
	                 germCN=z$germlinecopynumber,
	                 subclonalCN=z$subclonecopynumber,
                   subpercent=z$subpercent)  
	return(res)	
}

==> SomatiCA_1.6.0.tar.gz: SomatiCA/R/subclonality.R <==
subclonality <- function(segment, admix, bin=0.1, sigma=0.1){
### Written by Mengjie Chen, Nov 2012 ###
### Modified in Feb, 2012  
### Estimation of subclonality for each segment ###	
	
	if(class(segment)!="GRanges")
	stop("Wrong input format! Check the manual") 
	z <- as(segment, "data.frame")
	z$germlineA <- round(z$nRcorrected)*2*(z$medgLAF)
	z$germlineB <- round(z$nRcorrected)*2*(1-z$medgLAF)		
	z$nA <- (z$tRcorrected*2*(z$medLAF)-admix)/(1-admix)
	z$nB <- (z$tRcorrected*2*(1-z$medLAF)-admix)/(1-admix)
	z$nA[z$nA < 0] <- 0
	z$nB[z$nB < 0] <- 0
	
	z$germlineAinteger <- round(z$germlineA)
	z$germlineBinteger <- round(z$germlineB) 
	z$germlinecopynumber <- z$germlineAinteger+z$germlineBinteger
  z$germlinecopynumber[z$germlinecopynumber==1 & z$medgermlineLAF>0.2 ] <- 2
  z$somaCN[z$germlinecopynumber==0 ] <- 2
	z$event[z$germlinecopynumber==0] <- "="
  
  z$ratio <- (z$ratio-admix)/(1-admix) 
	z$ratio[z$ratio<0 ] <- 0 
  z$copyRatio <- ifelse(z$ratio >= 1, 
						  (z$germlinecopynumber+1)/(z$germlinecopynumber),
						  (z$germlinecopynumber-1)/(z$germlinecopynumber))
	
	z$subclonalP <- ifelse(z$ratio >= z$copyRatio, 
						   2-2*pnorm(z$ratio, z$copyRatio, sigma),
						   2*pnorm(z$ratio, z$copyRatio, sigma))
  
	z$clonality <- "=" 				
	z$clonality[z$subclonalP<=0.05] <- "subclonal"
	z$clonality[z$copyRatio!=1 & z$subclonalP>0.05 & abs(z$ratio - 1)>0.05 ] <- "clonal"
	z$clonality[z$ratio > 1.6] <- "clonal"
	z$clonality[abs(z$medgLAF-z$medLAF)<0.02 & z$event=="="] <- "="
  
	z$subpercent <- ifelse(z$clonality!="subclonal", 0, round(abs(1-z$ratio)*(z$germlinecopynumber), 3))					
	z$subclonalP[round(z$subpercent, 1)>=0.9] <- 1
	z$subclonalP[z$subpercent<0.1 & z$subpercent>0] <- 1
	z$clonality[round(z$subpercent, 1)>=0.9] <- "clonal"	
	z$clonality[z$subpercent<0.1 & z$subpercent>0] <- "="	
	z$subpercent[round(z$subpercent, 1)>=0.9] <- 1
	z$subpercent[z$subpercent<0.1] <- 0
	z$subpercent[z$clonality=="clonal"] <- 1
	z$subpercent <- floor(z$subpercent/bin)*bin
	z$clonality[z$subpercent==0] <- "="	
	z$subclonecopynumber <- ifelse(z$clonality == "=", z$germlinecopynumber, 														
                          ifelse(z$clonality == "clonal", round(z$germlinecopynumber*z$ratio),	
                          ifelse(z$ratio>1, 1 + z$germlinecopynumber, z$germlinecopynumber - 1)))
  z$clonality[z$germlinecopynumber==z$subclonecopynumber & z$somaCN==2] <- "="
	z$event[z$germlinecopynumber==z$subclonecopynumber & z$somaCN==2] <- "="
	z$subpercent[z$clonality=="="] <- 0
	z$clonality[z$ratio>1 & z$clonality=="subclonal"] <- "subclonal_gain"
	z$clonality[z$ratio<1 & z$clonality=="subclonal"] <- "subclonal_loss"
	z[, c("clonality", "event")] <- apply(z[, c("clonality", "event")], 2, as.character)
	z$event[z$clonality == "clonal" & z$germlinecopynumber > z$subclonecopynumber & z$event=="="] <- "Loss"
	z$event[z$clonality == "clonal" & z$germlinecopynumber < z$subclonecopynumber & z$event=="="] <- "Gain"
	res <- GRanges(seqnames=z$seqnames, 
	                 ranges=IRanges(start=z$start, end=z$end),
	                 medLAF=z$medLAF,
	                 medgLAF=z$medgLAF,
	                 ratio=z$ratio,
	                 somaCN=z$somaCN, 
	                 event=z$event,
	                 clonality=z$clonality,
	                 germCN=z$germlinecopynumber,
	                 subclonalCN=z$subclonecopynumber,
                   subpercent=z$subpercent)  
	return(res)	
}
